#include <WiFiClientSecure.h>
#include <base64.h>
#include <Arduino.h>
#include <time.h>
#include <utility>
#include "nextcloud_cal.h"
#include "tls_certificates.h"

Calendar downloadICSFile(const String& url, const String& startTime, const String& endTime, const String& username, const String& password) {
    WiFiClientSecure client;
    client.setCACert(letsencrypt_root_ca);

    // Construct full URL with query parameters
    String fullUrl = url + "?export&start=" + startTime + "&end=" + endTime + "&expand=1";
    Serial.println("Requesting URL: " + fullUrl);

    // Parse the host and path from the URL
    int index = fullUrl.indexOf('/');
    String host = fullUrl.substring(0, index);
    String path = fullUrl.substring(index);

    // Connect to the server
    if (!client.connect(host.c_str(), 443)) {
        Serial.println("Connection failed!");
        Serial.print("Host: ");
        Serial.println(host);
        return Calendar{};
    }

    // Encode credentials in Base64
    String credentials = username + ":" + password;
    String authHeader = "Authorization: Basic " + base64::encode(credentials);

    // Send the GET request with the Authorization header
    client.print(String("GET ") + path + " HTTP/1.1\r\n" +
                 "Host: " + host + "\r\n" +
                 authHeader + "\r\n" +
                 "Connection: close\r\n\r\n");

    // Read the response
    String response = "";
    while (client.connected() || client.available()) {
        response += client.readString();
    }

    // Check for HTTP status code (assuming response includes headers)
    int statusCodeStart = response.indexOf(" ") + 1;
    int statusCodeEnd = response.indexOf(" ", statusCodeStart);
    int statusCode = response.substring(statusCodeStart, statusCodeEnd).toInt();

    if (statusCode == 200) {
        // Strip headers if needed
        int headerEnd = response.indexOf("\r\n\r\n");
        if (headerEnd != -1) {
            response = response.substring(headerEnd + 4);
        }
        return parseVCalendar(response);
    } else {
        Serial.println("Failed to fetch: " + String(statusCode));
        return Calendar{};
    }
}

StartEnd calculateStartEnd() {
    struct tm timeinfo;
    if (!getLocalTime(&timeinfo)) {
        Serial.println("Failed to obtain time");
        return {0, 0}; // Return a struct with zero timestamps if time retrieval fails
    }

    // Calculate 'start' - 00:01 today
    timeinfo.tm_hour = 0;
    timeinfo.tm_min = 1;
    timeinfo.tm_sec = 0;
    time_t startTimestamp = mktime(&timeinfo);

    // Calculate 'end' - 23:59 10 days later
    timeinfo.tm_hour = 23;
    timeinfo.tm_min = 59;
    timeinfo.tm_sec = 59;
    timeinfo.tm_mday += 10; // Move forward 10 days
    time_t endTimestamp = mktime(&timeinfo);

    // Return a struct containing both Unix timestamps
    StartEnd result = {startTimestamp, endTimestamp};
    return result;
}

Calendar parseVCalendar(String vcalData) {
  Calendar calendar;
  VEvent currentEvent;
  bool inEvent = false;

  int startPos = 0;
  while (startPos < vcalData.length()) {
    int endPos = vcalData.indexOf("\n", startPos);
    if (endPos == -1) endPos = vcalData.length();

    String line = vcalData.substring(startPos, endPos);
    line.trim();

    if (line.startsWith("X-WR-CALNAME:")) {
      calendar.name = line.substring(13);
    } else if (line.startsWith("X-APPLE-CALENDAR-COLOR:")) {
      calendar.color = line.substring(25);
    } else if (line.startsWith("BEGIN:VEVENT")) {
      inEvent = true;
      currentEvent = VEvent();
    } else if (line.startsWith("END:VEVENT")) {
      inEvent = false;
      calendar.events.push_back(currentEvent);
    } else if (inEvent) {
      if (line.startsWith("DTSTAMP:")) {
        currentEvent.dtstamp = line.substring(8);
      } else if (line.startsWith("DTSTART:")) {
        currentEvent.dtstart = line.substring(8);
      } else if (line.startsWith("DTEND:")) {
        currentEvent.dtend = line.substring(6);
      } else if (line.startsWith("SUMMARY:")) {
        currentEvent.summary = line.substring(8);
      }
    }

    startPos = endPos + 1;
  }

  return calendar;
}
